"dat" <-
  function(...) {
    new("dat", ...)
  }
